@@ -24,6 +24,16 @@ open Lang_builtins
 
 let log = Log.make ["lang"; "run_process"]
 
+let () =
+  add_builtin "process.quote" ~cat:Sys
+    ~descr:
+      "Return a quoted copy of the given string, suitable for use as one \
+       argument in a command line, escaping all meta-characters. Warning: \
+       under Windows, the output is only suitable for use with programs that \
+       follow the standard Windows quoting conventions."
+    [("", Lang.string_t, None, None)] Lang.string_t (fun p ->
+      Lang.string (Filename.quote (Lang.to_string (List.assoc "" p))))
+
 let () =
   let ret_t =
     Lang.tuple_t
